/*
 * Copyright 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 * Danbooru Client is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Danbooru Client is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Danbooru Client. If not, see <http://www.gnu.org/licenses/>.
 */

#include "test_konachan.h"

#include <QLabel>

namespace Danbooru {

KonachanServiceTest::KonachanServiceTest(QUrl boardUrl):
    m_service(0),
    m_label(new QLabel())
{
    m_service = new KonachanDanbooruService(boardUrl);
    m_service->setParent(this);
    m_service->setMaximumAllowedRating(DanbooruPost::Explicit);
    m_service->setMaxPosts(1);
    connect(m_service, &DanbooruServiceBase::postDownloaded, this, &KonachanServiceTest::showPostData);
    connect(m_service, &DanbooruServiceBase::poolDownloaded, this, &KonachanServiceTest::showPoolData);
}

KonachanServiceTest::~KonachanServiceTest() {
    delete m_service;
    delete m_label;
}

void KonachanServiceTest::testPostService() {
    m_service->getPostList();
}

void KonachanServiceTest::testPoolService() {
    m_service->getPoolList(1 /*limit */);
}

void KonachanServiceTest::testPoolRetrieval(int postid) {
    m_service->getPool(postid);
}

void KonachanServiceTest::showPostData(DanbooruPost* post) {
    qDebug() << "Post File URL" << post->fileUrl().toString();
    qDebug() << "Post ID" << post->id();
    qDebug() << "Post tags" << post->tags();
    qDebug() << "Post rating" << post->rating();
    m_label->setPixmap(post->pixmap());
    m_label->show();
}

void KonachanServiceTest::showPoolData(DanbooruPool* pool) {
    qDebug() << "----";
    qDebug() << "Pool ID" << pool->id();
    qDebug() << "Pool name" << pool->name();
    qDebug() <<  "Pool description" << pool->description();
    qDebug() << "Pool post count" << pool->postCount();
//     qDebug() << "Post IDs" << pool->posts();

}

DanbooruServiceBase* KonachanServiceTest::service() const {
    return m_service;
}

} // namespace Danbooru